@@ -131,6 +131,9 @@ class AssistantView(tktextext.TextFrame):
         self._snapshots_per_main_file[key].append(self._current_snapshot)
 
         if msg.get("user_exception"):
+            if not msg["user_exception"].get("message", None):
+                msg["user_exception"]["message"] = "<no message>"
+                
             self._exception_info = msg["user_exception"]
             self._explain_exception(msg["user_exception"])
             if get_workbench().get_option("assistance.open_assistant_on_errors"):
@@ -158,10 +161,10 @@ class AssistantView(tktextext.TextFrame):
             )
             + "\n"
         )
-
-        if error_info.get("lineno") is not None and os.path.exists(
-            error_info["filename"]
-        ):
+        
+        if (error_info.get("lineno") is not None 
+            and error_info.get("filename")
+            and os.path.exists(error_info["filename"])):
             rst += "`%s, line %d <%s>`__\n\n" % (
                 os.path.basename(error_info["filename"]),
                 error_info["lineno"],
