@@ -8,6 +8,7 @@ import inspect
 import io
 import logging
 import os.path
+import platform
 import pkgutil
 import pydoc
 import signal
@@ -89,6 +90,7 @@ class VM:
         self._source_info_by_frame = {}
         site.sethelper()  # otherwise help function is not available
         pydoc.pager = pydoc.plainpager  # otherwise help command plays tricks
+        self._tweak_system_path()
         self._install_fake_streams()
         self._current_executor = None
         self._io_level = 0
@@ -285,10 +287,38 @@ class VM:
 
         with open(_CONFIG_FILENAME, "w") as fp:
             self._ini.write(fp)
+    
+    def _tweak_system_path(self):
+        """"allow easy calling of Python scripts """
+        
+        def prepend_if_missing(script_dir):
+            sys_path = os.environ.get("PATH", "")
+            if script_dir not in sys_path.split(os.pathsep):
+                os.environ["PATH"] = script_dir + os.pathsep + sys_path
+                
+        try:
+            if platform.system() == "Windows":
+                base_scripts = sys.prefix + "\\Scripts"
+            else:
+                base_scripts = sys.prefix + "/bin"
+            prepend_if_missing(base_scripts)
+            
+            if platform.system() == "Windows":
+                user_scripts = site.USER_SITE.replace("site-packages", "Scripts")
+            else:
+                user_scripts = site.USER_BASE + "/bin"
+            prepend_if_missing(user_scripts)
+            
+        except Exception:
+            logging.getLogger("thonny").exception("Couldn't tweak system path")
+            pass
 
     def _custom_import(self, *args, **kw):
         module = self._original_import(*args, **kw)
-
+        
+        if not hasattr(module, "__name__"):
+            return module
+        
         # module specific handlers
         for handler in self._import_handlers.get(module.__name__, []):
             try:
@@ -419,17 +449,23 @@ class VM:
     def _cmd_execute_system_command(self, cmd):
         # TODO: how to publish stdout as it arrives?
         env = dict(os.environ).copy()
-        env["PYTHONIOENCODING"] = "ascii"
-        proc = subprocess.Popen(
-            cmd.argv,
+        encoding = "utf-8"
+        env["PYTHONIOENCODING"] = encoding
+        popen_kw = dict(
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             shell=True,
             env=env,
             universal_newlines=True,
-            encoding="ascii",
-            errors="backslashreplace",
         )
+        
+        if sys.version_info >= (3,6):
+            popen_kw["errors"] = "backslashreplace"
+            popen_kw["encoding"] = encoding
+        
+        assert cmd.cmd_line.startswith("!")
+        cmd_line = cmd.cmd_line[1:]
+        proc = subprocess.Popen(cmd_line, **popen_kw)
         out, err = proc.communicate(input="")
         print(out, end="")
         print(err, file=sys.stderr, end="")
